@@ -3,8 +3,8 @@ PdfInfoExtractor
 
 """
 
-from utilities import ImagesExtractor, ClassifyFiles, extract_info
+from PdfInfoExtractor.utilities import ImagesExtractor, ClassifyFiles, extract_info
 
-__version__ = "0.1.11"
+__version__ = "0.1.12"
 __author__ = 'Steve Richards, Mehak Singal, Nidhish Kumar'
 # __credits__ = 'Argonne National Laboratory'
\ No newline at end of file
